@@ -51,13 +51,34 @@ class ModelLoader(Generic[GenericDbType]):
     @staticmethod
     async def create(model: GenericDbType, protection: AccessProtectIdentity, dto: PdModel,
                      **kwargs) -> GenericDbType:
-        entity_kwargs = {field: value for field, value in dto.dict().items() if value is not None}
+        entity_kwargs = {}
+        m2m_fields = {}
+        for field, value in dto.dict().items():
+            if value is None:
+                continue
+            if field.endswith('_id') or field.endswith('_ids'):
+                raw_field = field[:field.find("_id")]
+                if raw_field in model._meta.m2m_fields:
+                    m2m_model = model._meta.fields_map[raw_field].model
+                    if not isinstance(value, (list, set)):
+                        value = [value]
+                    m2m_entities = await m2m_model.filter(id__in=value)
+                    if len(m2m_entities) != len(value):
+                        raise InconsistencyError(message=f"Some {m2m_model.__name__} not found")
+                    m2m_fields[raw_field] = m2m_entities
+                else:
+                    entity_kwargs[field] = value
+            else:
+                entity_kwargs[field] = value
         try:
             entity = await model.create(**entity_kwargs)
         except IntegrityError as exception:
             raise integrity_error_format(exception)
         except ValueError as exception:
             raise InconsistencyError(exception)
+
+        for m2m_field, m2m_entities in m2m_fields.items():
+            await getattr(entity, m2m_field).add(*m2m_entities)
         return entity
 
     @staticmethod
@@ -99,8 +120,20 @@ class ModelLoader(Generic[GenericDbType]):
     async def update(model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity, dto: PdModel,
                      **kwargs) -> GenericDbType:
         entity = await ModelLoader.get_entity(model, entity_id)
+        m2m_fields = {}
         entity_kwargs = {field: value for field, value in dto.dict().items() if value is not None}
         for field, value in entity_kwargs.items():
+            if field.endswith('_id') or field.endswith('_ids'):
+                raw_field = field[:field.find("_id")]
+                if raw_field in model._meta.m2m_fields:
+                    m2m_model = model._meta.fields_map[raw_field].model
+                    if not isinstance(value, (list, set)):
+                        value = [value]
+                    m2m_entities = await m2m_model.filter(id__in=value)
+                    if len(m2m_entities) != len(value):
+                        raise InconsistencyError(message=f"Some {m2m_model.__name__} not found")
+                    m2m_fields[raw_field] = m2m_entities
+                    continue
             setattr(entity, field, value)
         try:
             await entity.save(update_fields=list(entity_kwargs.keys()))
@@ -108,6 +141,8 @@ class ModelLoader(Generic[GenericDbType]):
             raise integrity_error_format(exception)
         except ValueError as exception:
             raise InconsistencyError(exception)
+        for m2m_field, m2m_entities in m2m_fields.items():
+            await getattr(entity, m2m_field).add(*m2m_entities)
         return entity
 
     @staticmethod
